<?php

namespace Drupal\url_purge_aggregator\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for the Url Purge Aggregator module.
 */
class UrlPurgeAggregatorSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['url_purge_aggregator.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'url_purge_aggregator_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('url_purge_aggregator.settings');

    $form['cache_object_type'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Cache object type to purge'),
      '#default_value' => $config->get('cache_object_type') ?: [],
      '#options' => [
        'node' => $this->t('Node'),
      ],
      '#description' => $this->t('Select the cache object type you want to purge.'),
    ];

    $form['debug_messages'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Debug Messages'),
      '#default_value' => $config->get('debug_messages'),
      '#description' => $this->t('Print debug messages during execution.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('url_purge_aggregator.settings')
      ->set('debug_messages', $form_state->getValue('debug_messages'))
      ->set('cache_object_type', array_filter($form_state->getValue('cache_object_type')))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
