<?php

namespace Drupal\url_purge_aggregator;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\node\NodeInterface;

/**
 * Event subscriber to handle entity updates and deletions.
 */
class UrlPurgeAggregatorManager implements UrlPurgeAggregatorManagerInterface {

  /**
   * The entity purger service.
   *
   * @var \Drupal\url_purge_aggregator\UrlPurgeAggregatorQueuer
   */
  protected $queuer;

  /**
   * The configuration service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new EntityEventSubscriber.
   *
   * @param \Drupal\url_purge_aggregator\UrlPurgeAggregatorQueuer $queuer
   *   The entity purger service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger factory.
   */
  public function __construct(UrlPurgeAggregatorQueuer $queuer, ConfigFactoryInterface $config_factory, LoggerChannelFactoryInterface $logger_factory) {
    $this->queuer = $queuer;
    $this->configFactory = $config_factory;
    $this->logger = $logger_factory->get('url_purge_aggregator');
  }

  /**
   * {@inheritdoc}
   */
  public function addNodeUrlToPurgeQueue(EntityInterface $entity) {
    // If the is not active the node purge option or the entity is not
    // strop the process.
    if (!$this->isNodePurgeEnabled() || !$entity instanceof NodeInterface) {
      return;
    }
    try {
      $url = $entity->toUrl('canonical', ['absolute' => TRUE]);
      $this->queuer->addUrlToPurgeQueue($url);
      if ($this->isDebugEnabled()) {
        $this->logger->notice('Node added the queue: @url', ['@url' => $url->toString()]);
      }
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isNodePurgeEnabled(): bool {
    $config = $this->configFactory->get('url_purge_aggregator.settings');
    $cache_object_type = $config->get('cache_object_type');
    return !empty($cache_object_type['node']);
  }

  /**
   * {@inheritdoc}
   */
  public function isDebugEnabled(): bool {
    $config = $this->configFactory->get('url_purge_aggregator.settings');
    return (bool) $config->get('debug_messages');
  }

}
