<?php

namespace Drupal\url_purge_aggregator;

use Drupal\Core\Url;
use Drupal\purge\Plugin\Purge\Invalidation\InvalidationsServiceInterface;
use Drupal\purge\Plugin\Purge\Queue\QueueServiceInterface;
use Drupal\purge\Plugin\Purge\Queuer\QueuerInterface;
use Drupal\purge\Plugin\Purge\Queuer\QueuersServiceInterface;

/**
 * Add url to the purge queue.
 */
class UrlPurgeAggregatorQueuer implements UrlPurgeAggregatorQueuerInterface {

  /**
   * Queuer plugin.
   *
   * @var \Drupal\purge\Plugin\Purge\Queuer\QueuerInterface
   */
  protected $queuer;

  /**
   * Invalidation service.
   *
   * @var \Drupal\purge\Plugin\Purge\Invalidation\InvalidationsServiceInterface
   */
  protected $invalidationFactory;

  /**
   * Purge Queue service.
   *
   * @var \Drupal\purge\Plugin\Purge\Queue\QueueServiceInterface
   */
  protected $purgeQueue;

  /**
   * Constructor of the service.
   *
   * @param \Drupal\purge\Plugin\Purge\Queuer\QueuersServiceInterface $purge_queuers
   *   Purge Queuer service.
   * @param \Drupal\purge\Plugin\Purge\Invalidation\InvalidationsServiceInterface $invalidation_factory
   *   Invalidation service.
   * @param \Drupal\purge\Plugin\Purge\Queue\QueueServiceInterface $purge_queue
   *   Purge Queue service.
   */
  public function __construct(
    QueuersServiceInterface $purge_queuers,
    InvalidationsServiceInterface $invalidation_factory,
    QueueServiceInterface $purge_queue,
  ) {
    $queuers = $purge_queuers->get('url_purge_aggregator_queuer');
    if ($queuers instanceof QueuerInterface) {
      $this->queuer = $queuers;
    }
    $this->invalidationFactory = $invalidation_factory;
    $this->purgeQueue = $purge_queue;
  }

  /**
   * {@inheritdoc}
   */
  public function addUrlToPurgeQueue(Url $url) {
    $url_string = $url->toString();
    $invalidations = [];
    $invalidations[] = $this->invalidationFactory->get('url', $url_string);
    $this->purgeQueue->add($this->queuer, $invalidations);
  }

}
